@@ -116,9 +116,9 @@
 	conv <- att.get.ncdf(nc, 0, "Conventions")
 	# assuming "CF-1.0"
 	
-	zvar <- .varName(nc, varname, warn=warn)
+	zvar <- raster:::.varName(nc, varname, warn=warn)
 	
-	datatype <- .getRasterDTypeFromCDF( nc$var[[zvar]]$prec )
+	datatype <- raster:::.getRasterDTypeFromCDF( nc$var[[zvar]]$prec )
 	
 	dim3 <- 3
 	dims <- nc$var[[zvar]]$ndims
@@ -126,7 +126,7 @@
 		stop(zvar, ' only has a single dimension; I cannot make a RasterLayer from this')
 	} else if (dims == 4) { 
 		if (type != 'RasterQuadBrick') {
-			nlevs <- nc$var[[zvar]]$dim[[4]]$len
+			nlevs <- nc$var[[zvar]]$dim[[lvar]]$len
 			if (level <=0 ) {
 				level <- 1
 				if (nlevs > 1) {
@@ -163,6 +163,7 @@
 	resx <- (xrange[2] - xrange[1]) / (ncols-1)
 	rm(xx)
 
+	
 	yy <- nc$var[[zvar]]$dim[[2]]$vals
 	rs <- yy[-length(yy)] - yy[-1]
 	if (! isTRUE ( all.equal( min(rs), max(rs), tolerance=0.025, scale= min(rs)) ) ) {
@@ -189,23 +190,32 @@
 	if (a$hasatt) { unit <- a$value }
 	a <- att.get.ncdf(nc, zvar, "grid_mapping")
 	if ( a$hasatt ) { projection  <- a$value }
-
-	prj = list()
+	prj <- list()
 	if (!is.na(projection)) {
 		att <- nc$var[[projection]]
 		prj <- as.list(unlist(att))
 		# now parse .....
 		# projection(r) <- ...
 	}
+
+	
+	if (((tolower(substr(nc$var[[zvar]]$dim[[1]]$name, 1, 3)) == 'lon')  &
+		(tolower(substr(nc$var[[zvar]]$dim[[2]]$name, 1, 3)) == 'lat')) | 
+		(xrange[1] < -181 | xrange[2] > 181 | yrange[1] < -91 | yrange[2] > 91)) {
+			crs <- 'NA'
+	} else {
+		crs <- '+proj=longlat +datum=WGS84'
+	}
+
 		
 	if (type == 'RasterLayer') {
-		r <- raster(xmn=xrange[1], xmx=xrange[2], ymn=yrange[1], ymx=yrange[2], ncols=ncols, nrows=nrows)
+		r <- raster(xmn=xrange[1], xmx=xrange[2], ymn=yrange[1], ymx=yrange[2], ncols=ncols, nrows=nrows, crs=crs)
 		r <- .enforceGoodLayerNames(r, long_name)
 	} else if (type == 'RasterBrick') {
-		r <- brick(xmn=xrange[1], xmx=xrange[2], ymn=yrange[1], ymx=yrange[2], ncols=ncols, nrows=nrows)
+		r <- brick(xmn=xrange[1], xmx=xrange[2], ymn=yrange[1], ymx=yrange[2], ncols=ncols, nrows=nrows, crs=crs)
 		r@title <- long_name
 	} else if (type == 'RasterQuadBrick') {
-		r <- .quad(xmn=xrange[1], xmx=xrange[2], ymn=yrange[1], ymx=yrange[2], ncols=ncols, nrows=nrows)
+		r <- .quad(xmn=xrange[1], xmx=xrange[2], ymn=yrange[1], ymx=yrange[2], ncols=ncols, nrows=nrows, crs=crs)
 		r@title <- long_name	
 		if (lvar == 4) { 
 			dim3 <- 3 
@@ -218,9 +228,6 @@
 		r@steps  <- nc$var[[zvar]]$dim[[step3]]$len
 	}
 	
-	if (xrange[1] < -181 | xrange[2] > 181 | yrange[1] < -91 | yrange[2] > 91) {
-		projection(r) <- NA
-	}
 	r@file@name <- filename
 	r@file@toptobottom <- toptobottom
 	r@unit <- unit
@@ -259,7 +266,7 @@
 	if (type == 'RasterLayer') {
 		if (is.na(band) | is.null(band)) {
 			if (dims > 2) { 
-				stop(zvar, 'has mutliple layers, provide a "band" value between 1 and ', dims[dim3])
+				stop(zvar, ' has mutliple layers, provide a "band" value between 1 and ', dims[dim3])
 			} 
 		} else {
 			if (length(band) > 1) {
