@@ -13,7 +13,7 @@ if (!isGeneric("zoom")) {
 
 
 setMethod('zoom', signature(x='Raster'), 
-function(x, ext=drawExtent(), maxpixels=100000, layer=1, new=TRUE, ...) {
+function(x, ext=drawExtent(), maxpixels=100000, layer=1, new=TRUE, useRaster=TRUE, ...) {
 	if (missing(x)) {
 		stop('You must provide a Raster* object as first argument to this function')
 	}
@@ -22,7 +22,12 @@ function(x, ext=drawExtent(), maxpixels=100000, layer=1, new=TRUE, ...) {
 	if (nlayers(x) > 1) { 
 		x <- raster(x, layer) 
 	}
-	.plotraster2(x, maxpixels=maxpixels, ext=ext, ...) 	
+	if (useRaster) {
+		.plotraster2(x, maxpixels=maxpixels, ext=ext, ...) 	
+	} else {
+		.plotraster(x, col=col, maxpixels=maxpixels, add=add, ...) 
+	}
+		
 	return(invisible(ext))
 }
 )
